==> haskell-conduit-1.3.1.2-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conduit
version: 1.3.1.2
id: conduit-1.3.1.2-E2wpiTRwNV9HimJJXCCytL
key: conduit-1.3.1.2-E2wpiTRwNV9HimJJXCCytL
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: http://github.com/snoyberg/conduit
synopsis: Streaming data processing library.
description:
    `conduit` is a solution to the streaming data problem, allowing for production,
    transformation, and consumption of streams of data in constant memory. It is an
    alternative to lazy I\/O which guarantees deterministic resource handling.
    .
    For more information about conduit in general, and how this package in
    particular fits into the ecosystem, see [the conduit
    homepage](https://github.com/snoyberg/conduit#readme).
    .
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/conduit>.
category: Data, Conduit
abi: 35c2974c3e43c6929456afb917f2ceaa
exposed: True
exposed-modules:
    Conduit Data.Conduit Data.Conduit.Combinators
    Data.Conduit.Combinators.Stream Data.Conduit.Internal
    Data.Conduit.Internal.Fusion Data.Conduit.Internal.List.Stream
    Data.Conduit.Lift Data.Conduit.List
hidden-modules: Data.Conduit.Internal.Pipe
                Data.Conduit.Internal.Conduit Data.Conduit.Combinators.Unqualified
                Data.Streaming.FileRead Data.Streaming.Filesystem
import-dirs: /usr/lib/ghc-8.6.5/site-local/conduit-1.3.1.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/conduit-1.3.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/conduit-1.3.1.2
hs-libraries: HSconduit-1.3.1.2-E2wpiTRwNV9HimJJXCCytL
depends:
    base-4.12.0.0 bytestring-0.10.8.2 directory-1.3.3.0
    exceptions-0.10.3-L2x6PdAsyEqAgSjmGnIOPt filepath-1.4.2.1
    mono-traversable-1.0.13.0-BsCAyhWvXDy3vw1rlSUDnf mtl-2.2.2
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b
    resourcet-1.2.2-JLxEmnu4VEmKsSbOPjgbf0 text-1.2.3.1
    transformers-0.5.6.2 unix-2.7.2.2
    unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-conduit/html/conduit.haddock
haddock-html: /usr/share/doc/haskell-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-conduit-1.3.1.2-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conduit
version: 1.3.1.2
id: conduit-1.3.1.2-H13fTqo9FiUDKKswU2xRAM
key: conduit-1.3.1.2-H13fTqo9FiUDKKswU2xRAM
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: http://github.com/snoyberg/conduit
synopsis: Streaming data processing library.
description:
    `conduit` is a solution to the streaming data problem, allowing for production,
    transformation, and consumption of streams of data in constant memory. It is an
    alternative to lazy I\/O which guarantees deterministic resource handling.
    .
    For more information about conduit in general, and how this package in
    particular fits into the ecosystem, see [the conduit
    homepage](https://github.com/snoyberg/conduit#readme).
    .
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/conduit>.
category: Data, Conduit
abi: ff013277ab8181bfcc73661692dc7fe8
exposed: True
exposed-modules:
    Conduit Data.Conduit Data.Conduit.Combinators
    Data.Conduit.Combinators.Stream Data.Conduit.Internal
    Data.Conduit.Internal.Fusion Data.Conduit.Internal.List.Stream
    Data.Conduit.Lift Data.Conduit.List
hidden-modules: Data.Conduit.Internal.Pipe
                Data.Conduit.Internal.Conduit Data.Conduit.Combinators.Unqualified
                Data.Streaming.FileRead Data.Streaming.Filesystem
import-dirs: /usr/lib/ghc-8.6.5/site-local/conduit-1.3.1.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/conduit-1.3.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/conduit-1.3.1.2
hs-libraries: HSconduit-1.3.1.2-H13fTqo9FiUDKKswU2xRAM
depends:
    base-4.12.0.0 bytestring-0.10.8.2 directory-1.3.3.0
    exceptions-0.10.3-C2fkKAVjk4AA6i9Cl1i116 filepath-1.4.2.1
    mono-traversable-1.0.15.0-9RSDslIanQuFhJ8p2US6JY mtl-2.2.2
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b
    resourcet-1.2.2-2dmcTwjPeuF8zenLvwytIP text-1.2.3.1
    transformers-0.5.6.2 unix-2.7.2.2
    unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-conduit/html/conduit.haddock
haddock-html: /usr/share/doc/haskell-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
